@@ -111,7 +111,10 @@ def resolver_equal_or_better(
 ) -> bool:
     if resolver_a.to_str() == resolver_b.to_str():
         return True
-    if resolver_a.to_str(ignore_nested=True) != resolver_b.to_str(ignore_nested=True):
+    if resolver_a.all_filters_str() != resolver_b.all_filters_str():
+        return False
+    # check if rez b has appendix fields or other fields to return that A does not
+    if len(resolver_b.get_fields_to_return() - resolver_a.get_fields_to_return()) > 0:
         return False
     # now go to nesteds
     for (
